@@ -28,7 +28,6 @@ import (
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/intstr"
 	"sigs.k8s.io/controller-runtime/pkg/client"
-	"sigs.k8s.io/controller-runtime/pkg/controller/controllerutil"
 )
 
 var consoleName = "console-cr-form"
@@ -55,12 +54,11 @@ func deployConsole(reconciler *Reconciler, operator *appsv1.Deployment) {
 	pod := getPod(namespace, image, sa.Name, reconciler.OcpVersion, operator)
 	service := getService(namespace, reconciler.OcpVersion)
 	route := getRoute(namespace)
-	scheme := reconciler.Service.GetScheme()
 	// `inject-trusted-cabundle` ConfigMap only supported in OCP 4.2+
 	if semver.Compare(reconciler.OcpVersion, "v4.2") >= 0 || reconciler.OcpVersion == "" {
 		existing := &corev1.ConfigMap{}
 		new := getCaConfigMap(namespace)
-		controllerutil.SetOwnerReference(operator, new, scheme)
+		new.SetOwnerReferences(operator.GetOwnerReferences())
 		if err := reconciler.Service.Get(context.TODO(), types.NamespacedName{Name: new.Name, Namespace: new.Namespace}, existing); err != nil {
 			if errors.IsNotFound(err) {
 				log.Info("Creating ConfigMap ", new.Name)
@@ -73,7 +71,7 @@ func deployConsole(reconciler *Reconciler, operator *appsv1.Deployment) {
 		} else {
 			if !reflect.DeepEqual(existing.Labels, new.Labels) {
 				existing.Labels = new.Labels
-				controllerutil.SetOwnerReference(operator, existing, scheme)
+				existing.SetOwnerReferences(operator.GetOwnerReferences())
 				log.Info("Updating ConfigMap ", existing.Name)
 				if err := reconciler.Service.Update(context.TODO(), existing); err != nil {
 					log.Error("failed to update configmap", err)
@@ -89,7 +87,7 @@ func deployConsole(reconciler *Reconciler, operator *appsv1.Deployment) {
 	}
 	comparator := compare.NewMapComparator()
 	deltas := comparator.Compare(deployed, requested)
-	writer := write.New(reconciler.Service).WithOwnerController(operator, scheme)
+	writer := write.New(reconciler.Service).WithOwnerReferences(operator.GetOwnerReferences()...)
 	var hasUpdates bool
 	for resourceType, delta := range deltas {
 		if !delta.HasChanges() {
