@@ -28,7 +28,7 @@ import (
 	consolev1 "github.com/openshift/api/console/v1"
 	oimagev1 "github.com/openshift/api/image/v1"
 	routev1 "github.com/openshift/api/route/v1"
-	operatorsv1alpha1 "github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
+	operatorsv1alpha1 "github.com/operator-framework/api/pkg/operators/v1alpha1"
 	"github.com/pavel-v-chernykh/keystore-go"
 	"golang.org/x/mod/semver"
 	appsv1 "k8s.io/api/apps/v1"
@@ -163,11 +163,6 @@ func (reconciler *Reconciler) Reconcile(request reconcile.Request) (reconcile.Re
 	if err != nil {
 		return reconcile.Result{}, err
 	}
-	if hasUpdates && status.SetProvisioning(instance) {
-		return reconciler.UpdateObj(instance)
-	} else if !hasUpdates {
-		log.Debug("Reconcile loop did not find any resource changes to apply")
-	}
 
 	// Check the KieServer ConfigMaps for necessary changes
 	reconciler.checkKieServerConfigMap(instance, env)
@@ -187,31 +182,35 @@ func (reconciler *Reconciler) Reconcile(request reconcile.Request) (reconcile.Re
 		return reconcile.Result{}, err
 	}
 
-	// Update CR if needed
-	if reconciler.hasSpecChanges(instance, cachedInstance) {
-		if status.SetProvisioning(instance) && instance.ResourceVersion == cachedInstance.ResourceVersion {
-			return reconciler.UpdateObj(instance)
-		}
-		return reconcile.Result{Requeue: true}, nil
-	}
-	if reconciler.hasStatusChanges(instance, cachedInstance) {
-		if instance.ResourceVersion == cachedInstance.ResourceVersion {
-			return reconciler.UpdateObj(instance)
-		}
-		return reconcile.Result{Requeue: true}, nil
-	}
-	if status.SetDeployed(instance) {
-		if instance.ResourceVersion == cachedInstance.ResourceVersion {
-			return reconciler.UpdateObj(instance)
-		}
-		return reconcile.Result{Requeue: true}, nil
-	}
-
-	return reconcile.Result{}, nil
+	// Update CR Status if needed
+	return reconciler.checkStatus(instance, cachedInstance, hasUpdates)
 }
 
-func (reconciler *Reconciler) reconcileResources(instance *api.KieApp, requestedResources []resource.KubernetesResource, deployed map[reflect.Type][]resource.KubernetesResource) (bool, error) {
-	writer := write.New(reconciler.Service).WithOwnerController(instance, reconciler.Service.GetScheme())
+func (reconciler *Reconciler) checkStatus(instance, cachedInstance *api.KieApp, hasUpdates bool) (reconcile.Result, error) {
+	var requeue bool
+	if hasUpdates {
+		requeue = status.SetProvisioning(instance)
+	} else {
+		requeue = status.SetDeployed(instance)
+	}
+	return reconciler.updateStatus(instance, cachedInstance, requeue)
+}
+
+func (reconciler *Reconciler) updateStatus(instance, cachedInstance *api.KieApp, requeue bool) (reconcile.Result, error) {
+	if reconciler.hasStatusChanges(instance, cachedInstance) {
+		if instance.ResourceVersion == cachedInstance.ResourceVersion {
+			if err := reconciler.Service.Status().Update(context.TODO(), instance); err != nil {
+				return reconcile.Result{}, err
+			}
+		} else {
+			return reconcile.Result{Requeue: true}, nil
+		}
+	}
+	return reconcile.Result{Requeue: requeue}, nil
+}
+
+func (reconciler *Reconciler) reconcileResources(ownerController metav1.Object, requestedResources []resource.KubernetesResource, deployed map[reflect.Type][]resource.KubernetesResource) (bool, error) {
+	writer := write.New(reconciler.Service).WithOwnerController(ownerController, reconciler.Service.GetScheme())
 	//Compare what's deployed with what should be deployed
 	requested := compare.NewMapBuilder().Add(requestedResources...).ResourceMap()
 	comparator := getComparator()
@@ -248,7 +247,6 @@ func isNamespaced(resource resource.KubernetesResource) bool {
 
 func getComparator() compare.MapComparator {
 	resourceComparator := compare.DefaultComparator()
-
 	dcType := reflect.TypeOf(oappsv1.DeploymentConfig{})
 	defaultDCComparator := resourceComparator.GetComparator(dcType)
 	resourceComparator.SetComparator(dcType, func(deployed resource.KubernetesResource, requested resource.KubernetesResource) bool {
@@ -260,9 +258,11 @@ func getComparator() compare.MapComparator {
 			}
 			trigger1 := dc1.Spec.Triggers[i]
 			trigger2 := dc2.Spec.Triggers[i]
-			if trigger1.ImageChangeParams != nil && trigger2.ImageChangeParams != nil && trigger2.ImageChangeParams.From.Namespace == "" {
-				//This value is generated based on image stream being found in current or openshift project:
-				trigger1.ImageChangeParams.From.Namespace = ""
+			if trigger2.ImageChangeParams != nil && trigger1.ImageChangeParams != nil {
+				if trigger2.ImageChangeParams.From.Namespace == "" {
+					//This value is generated based on image stream being found in current or openshift project:
+					trigger1.ImageChangeParams.From.Namespace = ""
+				}
 			}
 		}
 		return defaultDCComparator(deployed, requested)
@@ -316,16 +316,19 @@ func setDeploymentStatus(instance *api.KieApp, resources []resource.KubernetesRe
 
 func (reconciler *Reconciler) verifyExternalReferences(cr *api.KieApp) error {
 	var err error
+
 	if cr.Status.Applied.Auth != nil && cr.Status.Applied.Auth.RoleMapper != nil {
 		err = reconciler.verifyExternalReference(cr.GetNamespace(), cr.Status.Applied.Auth.RoleMapper.From)
 	}
-	if err == nil && cr.Status.Applied.Objects.Console.GitHooks != nil {
-		err = reconciler.verifyExternalReference(cr.GetNamespace(), cr.Status.Applied.Objects.Console.GitHooks.From)
+	if cr.Status.Applied.Objects.Console != nil {
+		if err == nil && cr.Status.Applied.Objects.Console.GitHooks != nil {
+			err = reconciler.verifyExternalReference(cr.GetNamespace(), cr.Status.Applied.Objects.Console.GitHooks.From)
+		}
 	}
 	return err
 }
 
-func (reconciler *Reconciler) verifyExternalReference(namespace string, ref *corev1.ObjectReference) error {
+func (reconciler *Reconciler) verifyExternalReference(namespace string, ref *api.ObjRef) error {
 	if ref == nil {
 		return nil
 	}
@@ -359,33 +362,16 @@ func getRequestedRoutes(env api.Environment, instance *api.KieApp) []resource.Ku
 	return requestedRoutes
 }
 
-func (reconciler *Reconciler) hasSpecChanges(instance, cached *api.KieApp) bool {
-	if !reflect.DeepEqual(instance.Spec, cached.Spec) {
-		return true
-	}
-	if len(instance.Spec.Objects.Servers) > 0 {
-		if len(instance.Spec.Objects.Servers) != len(cached.Spec.Objects.Servers) {
-			return true
-		}
-		for i := range instance.Spec.Objects.Servers {
-			if !reflect.DeepEqual(instance.Spec.Objects.Servers[i], cached.Spec.Objects.Servers[i]) {
-				return true
-			}
-		}
-	}
-	return false
-}
-
-func (reconciler *Reconciler) hasStatusChanges(instance, cached *api.KieApp) bool {
-	if !reflect.DeepEqual(instance.Status, cached.Status) {
+func (reconciler *Reconciler) hasStatusChanges(instance, cachedInstance *api.KieApp) bool {
+	if !reflect.DeepEqual(instance.Status, cachedInstance.Status) {
 		return true
 	}
 	if len(instance.Status.Applied.Objects.Servers) > 0 {
-		if len(instance.Status.Applied.Objects.Servers) != len(cached.Status.Applied.Objects.Servers) {
+		if len(instance.Status.Applied.Objects.Servers) != len(cachedInstance.Status.Applied.Objects.Servers) {
 			return true
 		}
 		for i := range instance.Status.Applied.Objects.Servers {
-			if !reflect.DeepEqual(instance.Status.Applied.Objects.Servers[i], cached.Status.Applied.Objects.Servers[i]) {
+			if !reflect.DeepEqual(instance.Status.Applied.Objects.Servers[i], cachedInstance.Status.Applied.Objects.Servers[i]) {
 				return true
 			}
 		}
@@ -395,8 +381,7 @@ func (reconciler *Reconciler) hasStatusChanges(instance, cached *api.KieApp) boo
 
 func (reconciler *Reconciler) setFailedStatus(instance *api.KieApp, reason api.ReasonType, err error) {
 	status.SetFailed(instance, reason, err)
-	_, updateError := reconciler.UpdateObj(instance)
-	if updateError != nil {
+	if updateError := reconciler.Service.Status().Update(context.TODO(), instance); updateError != nil {
 		log.Warn("Unable to update object after receiving failed status. ", err)
 	}
 }
@@ -409,7 +394,7 @@ func (reconciler *Reconciler) checkImageStreamTag(name, namespace string) bool {
 		result = append(result, "latest")
 	}
 	tagName := fmt.Sprintf("%s:%s", result[0], result[1])
-	_, err := reconciler.Service.ImageStreamTags(namespace).Get(tagName, metav1.GetOptions{})
+	_, err := reconciler.Service.ImageStreamTags(namespace).Get(context.TODO(), tagName, metav1.GetOptions{})
 	if err != nil {
 		log.Debug("Object does not exist")
 		return false
@@ -418,7 +403,7 @@ func (reconciler *Reconciler) checkImageStreamTag(name, namespace string) bool {
 }
 
 // Create local ImageStreamTag
-func (reconciler *Reconciler) createLocalImageTag(tagRefName string, cr *api.KieApp) error {
+func (reconciler *Reconciler) createLocalImageTag(tagRefName, imageURL string, cr *api.KieApp) error {
 	result := strings.Split(tagRefName, ":")
 	if len(result) == 1 {
 		result = append(result, "latest")
@@ -426,8 +411,11 @@ func (reconciler *Reconciler) createLocalImageTag(tagRefName string, cr *api.Kie
 	product := defaults.GetProduct(cr.Status.Applied.Environment)
 	tagName := fmt.Sprintf("%s:%s", result[0], result[1])
 	imageName := tagName
-	major, _, _ := defaults.MajorMinorMicro(cr.Status.Applied.Version)
+	major, _, _ := defaults.GetMajorMinorMicro(cr.Status.Applied.Version)
 	regContext := fmt.Sprintf("%s-%s", product, major)
+	if _, _, imageContext := defaults.GetImage(imageURL); imageContext != "" {
+		regContext = imageContext
+	}
 
 	// default registry settings
 	registry := &api.KieAppRegistry{
@@ -481,7 +469,7 @@ func (reconciler *Reconciler) createLocalImageTag(tagRefName string, cr *api.Kie
 	}
 	log := log.With("kind", isnew.GetObjectKind().GroupVersionKind().Kind, "name", isnew.Name, "from", isnew.Tag.From.Name, "namespace", isnew.Namespace)
 	log.Info("Creating")
-	_, err := reconciler.Service.ImageStreamTags(isnew.Namespace).Create(isnew)
+	_, err := reconciler.Service.ImageStreamTags(isnew.Namespace).Create(context.TODO(), isnew, metav1.CreateOptions{})
 	if err != nil && !errors.IsAlreadyExists(err) {
 		log.Error("Issue creating object. ", err)
 		return err
@@ -605,6 +593,7 @@ func (reconciler *Reconciler) setConsoleHost(cr *api.KieApp, env api.Environment
 func (reconciler *Reconciler) getKubernetesResources(cr *api.KieApp, env api.Environment) []resource.KubernetesResource {
 	var resources []resource.KubernetesResource
 	objects := filterOmittedObjects(getCustomObjects(env))
+	objects = reconciler.imageStreams(cr, objects)
 	for _, obj := range objects {
 		resources = append(resources, reconciler.getCustomObjectResources(obj, cr)...)
 	}
@@ -615,6 +604,44 @@ func (reconciler *Reconciler) getKubernetesResources(cr *api.KieApp, env api.Env
 	return resources
 }
 
+func (reconciler *Reconciler) imageStreams(cr *api.KieApp, objects []api.CustomObject) []api.CustomObject {
+	for i, object := range objects {
+		// DC logic
+		if len(object.BuildConfigs) == 0 {
+			for index := range object.DeploymentConfigs {
+				for ti, trigger := range object.DeploymentConfigs[index].Spec.Triggers {
+					if trigger.Type == oappsv1.DeploymentTriggerOnImageChange {
+						for _, containerName := range trigger.ImageChangeParams.ContainerNames {
+							for _, container := range object.DeploymentConfigs[index].Spec.Template.Spec.Containers {
+								if container.Name == containerName {
+									objects[i].DeploymentConfigs[index].Spec.Triggers[ti].ImageChangeParams.From.Namespace, _ = reconciler.ensureImageStream(
+										trigger.ImageChangeParams.From.Name,
+										trigger.ImageChangeParams.From.Namespace,
+										container.Image,
+										cr,
+									)
+								}
+							}
+						}
+					}
+				}
+			}
+		}
+		// BC logic
+		for index := range object.BuildConfigs {
+			if object.BuildConfigs[index].Spec.Strategy.Type == buildv1.SourceBuildStrategyType {
+				objects[i].BuildConfigs[index].Spec.Strategy.SourceStrategy.From.Namespace, _ = reconciler.ensureImageStream(
+					object.BuildConfigs[index].Spec.Strategy.SourceStrategy.From.Name,
+					object.BuildConfigs[index].Spec.Strategy.SourceStrategy.From.Namespace,
+					"",
+					cr,
+				)
+			}
+		}
+	}
+	return objects
+}
+
 func getCustomObjects(env api.Environment) []api.CustomObject {
 	var objects []api.CustomObject
 	objects = append(objects, env.Console)
@@ -719,17 +746,6 @@ func (reconciler *Reconciler) getCustomObjectResources(object api.CustomObject,
 	}
 	for index := range object.DeploymentConfigs {
 		object.DeploymentConfigs[index].SetGroupVersionKind(oappsv1.GroupVersion.WithKind("DeploymentConfig"))
-		if len(object.BuildConfigs) == 0 {
-			for ti, trigger := range object.DeploymentConfigs[index].Spec.Triggers {
-				if trigger.Type == oappsv1.DeploymentTriggerOnImageChange {
-					object.DeploymentConfigs[index].Spec.Triggers[ti].ImageChangeParams.From.Namespace, _ = reconciler.ensureImageStream(
-						trigger.ImageChangeParams.From.Name,
-						trigger.ImageChangeParams.From.Namespace,
-						cr,
-					)
-				}
-			}
-		}
 		allObjects = append(allObjects, &object.DeploymentConfigs[index])
 	}
 	for index := range object.Services {
@@ -750,12 +766,6 @@ func (reconciler *Reconciler) getCustomObjectResources(object api.CustomObject,
 	}
 	for index := range object.BuildConfigs {
 		object.BuildConfigs[index].SetGroupVersionKind(buildv1.GroupVersion.WithKind("BuildConfig"))
-		if object.BuildConfigs[index].Spec.Strategy.Type == buildv1.SourceBuildStrategyType {
-			object.BuildConfigs[index].Spec.Strategy.SourceStrategy.From.Namespace, _ = reconciler.ensureImageStream(
-				object.BuildConfigs[index].Spec.Strategy.SourceStrategy.From.Name,
-				object.BuildConfigs[index].Spec.Strategy.SourceStrategy.From.Namespace, cr,
-			)
-		}
 		allObjects = append(allObjects, &object.BuildConfigs[index])
 	}
 	for index := range object.ConfigMaps {
@@ -765,13 +775,13 @@ func (reconciler *Reconciler) getCustomObjectResources(object api.CustomObject,
 	return allObjects
 }
 
-func (reconciler *Reconciler) ensureImageStream(name string, namespace string, cr *api.KieApp) (string, error) {
+func (reconciler *Reconciler) ensureImageStream(name, namespace, imageURL string, cr *api.KieApp) (string, error) {
 	if cr.Status.Applied.ImageRegistry != nil {
 		if reconciler.checkImageStreamTag(name, cr.Namespace) {
 			return cr.Namespace, nil
 		}
 		log.Warnf("ImageStreamTag %s/%s doesn't exist.", namespace, name)
-		err := reconciler.createLocalImageTag(name, cr)
+		err := reconciler.createLocalImageTag(name, imageURL, cr)
 		if err != nil {
 			log.Error(err)
 			return namespace, err
@@ -785,7 +795,7 @@ func (reconciler *Reconciler) ensureImageStream(name string, namespace string, c
 		return cr.Namespace, nil
 	} else {
 		log.Warnf("ImageStreamTag %s/%s doesn't exist.", namespace, name)
-		err := reconciler.createLocalImageTag(name, cr)
+		err := reconciler.createLocalImageTag(name, imageURL, cr)
 		if err != nil {
 			log.Error(err)
 			return namespace, err
